# InspectionWithdrawRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**internal_user_identifier** | **str** | Max length 100 characters | [optional] 
**internal_user_name** | **str** | Max length 100 characters | [optional] 
**reason_for_withdrawal** | [**InspectionReasonForWithdrawal**](InspectionReasonForWithdrawal.md) |  | 
**withdrawal_details** | **str** | Max length 500 characters | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

